==> jc-1.4.0.tar.gz: ppg/util/Block.h <==
// class ppg.util.Block

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ca9b4312347f8a96 ppg_util_Block
// @dep_class 5146bf5a25ced51e ppg_util_Item

// header file dependencies
// @dep_header ppg_util_Item

#include "ppg/util/Item.h"

#ifndef _JC_ppg_util_Block_H_
#define _JC_ppg_util_Block_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_ppg_util_Block$object;
struct _jc_ppg_util_Item$object;

// Typedefs
typedef struct _jc_ppg_util_Block$sub_refs	_jc_ppg_util_Block$sub_refs;
typedef struct _jc_ppg_util_Block$sub_nonrefs	_jc_ppg_util_Block$sub_nonrefs;
typedef struct _jc_ppg_util_Block$refs	_jc_ppg_util_Block$refs;
typedef struct _jc_ppg_util_Block$nonrefs	_jc_ppg_util_Block$nonrefs;
typedef struct _jc_ppg_util_Block$object	_jc_ppg_util_Block$object;

typedef const struct _jc_ppg_util_Block$vmethods	_jc_ppg_util_Block$vmethods;
typedef const struct _jc_ppg_util_Block$vtable	_jc_ppg_util_Block$vtable;
typedef const struct _jc_ppg_util_Block$vtype	_jc_ppg_util_Block$vtype;

// Constructors
extern void _jc_ppg_util_Block$method$_init$6b60cd0a3dd59db6(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_ppg_util_Block$object *, jint);

// Virtual methods
extern void _jc_ppg_util_Block$method$add$6658918dc4903ba7(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_ppg_util_Item$object *);
extern jint _jc_ppg_util_Block$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_ppg_util_Block$object *, jint, jint, jint, jint, jboolean, jboolean);
extern void _jc_ppg_util_Block$method$free$564111a2cbc836ef(_jc_env *, struct _jc_ppg_util_Block$object *);
extern jint _jc_ppg_util_Block$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_java_io_Writer$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_ppg_util_Block$method_info$add$6658918dc4903ba7;
extern _jc_method _jc_ppg_util_Block$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_ppg_util_Block$method_info$free$564111a2cbc836ef;
extern _jc_method _jc_ppg_util_Block$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_ppg_util_Block$vmethods {
	void	(*add$6658918dc4903ba7)(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_ppg_util_Item$object *);
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_ppg_util_Block$object *, jint, jint, jint, jint, jboolean, jboolean);
	void	(*free$564111a2cbc836ef)(_jc_env *, struct _jc_ppg_util_Block$object *);
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_java_io_Writer$object *, jint, jint);
};

// Vtable
struct _jc_ppg_util_Block$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_util_Item$vmethods	ppg_util_Item;
	_jc_ppg_util_Block$vmethods	ppg_util_Block;
};

// Vtype
struct _jc_ppg_util_Block$vtype {
	_jc_type			type;
	_jc_ppg_util_Block$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_util_Block$sub_refs {
	struct _jc_ppg_util_Block$object	*parent;
	struct _jc_ppg_util_Item$object	*first;
	struct _jc_ppg_util_Item$object	*last;
};

// Reference instance fields (object)
struct _jc_ppg_util_Block$refs {
    _jc_ppg_util_Block$sub_refs	ppg_util_Block;
    _jc_ppg_util_Item$sub_refs	ppg_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_util_Block$sub_nonrefs {
	jint	indent;
};

// Non-reference instance fields (object)
struct _jc_ppg_util_Block$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_util_Item$sub_nonrefs	ppg_util_Item;
    _jc_ppg_util_Block$sub_nonrefs	ppg_util_Block;
};

// Object instance structure
struct _jc_ppg_util_Block$object {
	_jc_ppg_util_Block$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_util_Block$vtype	*vtype;
	_jc_ppg_util_Block$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_util_Block$vtype _jc_ppg_util_Block$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_util_Block, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_util_Block$class_object;

#endif	/* _JC_ppg_util_Block_H_ */

==> jc-1.4.6.tar.gz: ppg/util/Block.h <==
// class ppg.util.Block

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ca9b4312347f8a96 ppg_util_Block
// @dep_class 5146bf5a25ced51e ppg_util_Item

// header file dependencies
// @dep_header ppg_util_Item

#include "ppg/util/Item.h"

#ifndef _JC_ppg_util_Block_H_
#define _JC_ppg_util_Block_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_ppg_util_Block$object;
struct _jc_ppg_util_Item$object;

// Typedefs
typedef struct _jc_ppg_util_Block$sub_refs	_jc_ppg_util_Block$sub_refs;
typedef struct _jc_ppg_util_Block$sub_nonrefs	_jc_ppg_util_Block$sub_nonrefs;
typedef struct _jc_ppg_util_Block$refs	_jc_ppg_util_Block$refs;
typedef struct _jc_ppg_util_Block$nonrefs	_jc_ppg_util_Block$nonrefs;
typedef struct _jc_ppg_util_Block$object	_jc_ppg_util_Block$object;

typedef const struct _jc_ppg_util_Block$vmethods	_jc_ppg_util_Block$vmethods;
typedef const struct _jc_ppg_util_Block$vtable	_jc_ppg_util_Block$vtable;
typedef const struct _jc_ppg_util_Block$vtype	_jc_ppg_util_Block$vtype;

// Constructors
extern void _jc_ppg_util_Block$method$_init$6b60cd0a3dd59db6(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_ppg_util_Block$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_ppg_util_Block$method$add$6658918dc4903ba7(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_ppg_util_Item$object *) _JC_JCNI_ATTR;
extern jint _jc_ppg_util_Block$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_ppg_util_Block$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
extern void _jc_ppg_util_Block$method$free$564111a2cbc836ef(_jc_env *, struct _jc_ppg_util_Block$object *) _JC_JCNI_ATTR;
extern jint _jc_ppg_util_Block$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_util_Block$method_info$add$6658918dc4903ba7;
extern _jc_method _jc_ppg_util_Block$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_ppg_util_Block$method_info$free$564111a2cbc836ef;
extern _jc_method _jc_ppg_util_Block$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_ppg_util_Block$vmethods {
	void	(*add$6658918dc4903ba7)(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_ppg_util_Item$object *) _JC_JCNI_ATTR;
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_ppg_util_Block$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
	void	(*free$564111a2cbc836ef)(_jc_env *, struct _jc_ppg_util_Block$object *) _JC_JCNI_ATTR;
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_ppg_util_Block$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_util_Block$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_util_Item$vmethods	ppg_util_Item;
	_jc_ppg_util_Block$vmethods	ppg_util_Block;
};

// Vtype
struct _jc_ppg_util_Block$vtype {
	_jc_type			type;
	_jc_ppg_util_Block$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_util_Block$sub_refs {
	struct _jc_ppg_util_Block$object	*parent;
	struct _jc_ppg_util_Item$object	*first;
	struct _jc_ppg_util_Item$object	*last;
};

// Reference instance fields (object)
struct _jc_ppg_util_Block$refs {
    _jc_ppg_util_Block$sub_refs	ppg_util_Block;
    _jc_ppg_util_Item$sub_refs	ppg_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_util_Block$sub_nonrefs {
	jint	indent;
};

// Non-reference instance fields (object)
struct _jc_ppg_util_Block$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_util_Item$sub_nonrefs	ppg_util_Item;
    _jc_ppg_util_Block$sub_nonrefs	ppg_util_Block;
};

// Object instance structure
struct _jc_ppg_util_Block$object {
	_jc_ppg_util_Block$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_util_Block$vtype	*vtype;
	_jc_ppg_util_Block$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_util_Block$vtype _jc_ppg_util_Block$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_util_Block, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_util_Block$class_object;

#endif	/* _JC_ppg_util_Block_H_ */
